#!/bin/bash
# AB-README_RUNME.sh
#
# DESCRIPTION:
# 	This script and associated data files produce high quality PDFS of the Holy-Bible---Mori-Atas---Mori-Atas-Bible
#	Developed and Coprighted by Nainoia Inc, PO Box 462, Bellefonte, PA 16823, (814) 470-8028, https://NAINOIA-INC.signedon.net
#	Copyright 2020, Creative Commons Attribution 4.0 International, https://creativecommons.org/licenses/by/4.0/
#
# OPERATION:
#	AB-README_RUNME.sh	`						// Help and cat the script
#	AB-README_RUNME.sh ALL						// Build all PDFs types
#	AB-README_RUNME.sh +PO +LU +NT +ON +OO +EP	// Build all selected type(s):  POD | LULU | NEW TESTAMENT | ONLINE | ONE-ONLINE | EPUB COVER
#
# FILETYPES:
#	[prefix].[suffix]							// Online cover page + interior
#	[prefix]---STUDY.[suffix]					// Online cover page + interior, wide margin study format
#	[prefix]---POD_KDP_ALL_BODY.[suffix]		// Print on demand interior for Amazon KDP specifications
#	[prefix]---POD_KDP_ALL_COVER.[suffix]		// Print on demand cover for Amazon KDP specifications
#	[prefix]---POD_KDP_X22_BODY.[suffix]		// Print on demand interior 22 books for Amazon KDP specifications
#	[prefix]---POD_KDP_X22_COVER.[suffix]		// Print on demand cover 22 books for Amazon KDP specifications
#	[prefix]---POD_KDP_NEW_BODY.[suffix]		// Print on demand interior New Testament for Amazon KDP specifications
#	[prefix]---POD_KDP_NEW_COVER.[suffix]		// Print on demand cover New Testament for Amazon KDP specifications
#	[prefix]---POD_LULU_ALL_BODY.[suffix]		// Print on demand interior paperback for LuLu specifications
#	[prefix]---POD_LULU_ALL_COVER.[suffix]		// Print on demand cover for LuLu specifications
#	[prefix]---POD_LULU_X22_BODY.[suffix]		// Print on demand interior 22 books paperback for LuLu specifications
#	[prefix]---POD_LULU_X22_COVER.[suffix]		// Print on demand cover 22 books for LuLu specifications
#	[prefix]---POD_LULU_NEW_BODY.[suffix]		// Print on demand interior paperback New Testament for LuLu specifications
#	[prefix]---POD_LULU_NEW_COVER.[suffix]		// Print on demand cover New Testament for LuLu specifications
#	[prefix]---POD_LULU_HAR_BODY.[suffix]		// Print on demand interior hardback for LuLu specifications
#	[prefix]---POD_LULU_HAR_COVER.[suffix]		// Print on demand cover hardback for LuLu specifications
#	[prefix]---POD_JOHN_BODY.[suffix]			// Print on demand interior Genesis, John and Revelation for Amazon KDP and Lulu specifications
#	[prefix]---POD_JOHN_COVER.[suffix]			// Print on demand cover Genesis, John and Revelation for Amazon KDP and Lulu specifications
#	[prefix]---POD_LULU_JOHN_BODY.[suffix]		// Print on demand RTL interior Genesis, John and Revelation for Lulu specifications
#
error_exit()
{
	echo "${1:-"Unknown Error"}" 1>&2
	exit 1
}
SPEED="../AB-Speedata/bin/sp"

if [ "$#" = "0" ] ; then echo "ERROR, NO ARGUMENTS `basename "$0"`, IN DIRECTORY `dirname "$0"` IN PWD `pwd`"; fi
name="---Aionian-Edition"
if ( [ "$1" = "+ALL" ] || [[ "${@#+ON}" != "$@" ]] || [[ "${@#+OO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---Aionian-Edition---STUDY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+ON}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---EPUB_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+EP}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_KDP_ALL_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_KDP_ALL_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_KDP_X22_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_KDP_X22_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+PO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_JOHN_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+JO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_JOHN_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+JO}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_KDP_NEW_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+NT}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_KDP_NEW_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+NT}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_LULU_ALL_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_LULU_ALL_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_LULU_X22_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_LULU_X22_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_LULU_NEW_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_LULU_NEW_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

name="---POD_LULU_HAR_BODY"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi
name="---POD_LULU_HAR_COVER"
if ( [ "$1" = "+ALL" ] || [[ "${@#+LU}" != "$@" ]] ) && [ -f bible_layout$name.xml ] ; then $SPEED --config bible_config.cfg  --jobname=Holy-Bible---Mori-Atas---Mori-Atas-Bible$name --filter=bible_luachk$name.lua --layout=bible_layout$name.xml || error_exit "ERROR Holy-Bible---Mori-Atas---Mori-Atas-Bible$name.pdf"; fi

echo "SPEEDATA Holy-Bible---Mori-Atas---Mori-Atas-Bible: SCRIPT SUCCESS!"
